@@ -1,10 +1,6 @@
 import random
 import math
-import itertools
-from collections import defaultdict, Counter, OrderedDict
-from collections.abc import Iterable, Iterator, Generator, Collection
-import sys, datetime
-from pathlib import Path
+import datetime
 import numpy as np
 import pandas as pd
 import torch
@@ -14,6 +10,60 @@ from dl2050utils.core import *
 from dl2050utils.ju import in_ipynb
 T = torch.tensor
 
+def norm(x):
+    m,s = x.mean(), x.std()
+    return (x-m)/s if s>0 else x
+
+def frmt_n(n): return f'{n:,}'.replace(',','.')
+
+def show_clsf_stats(y, c, cls, c_szs, c_dist):
+    df = pd.concat([
+        pd.DataFrame(np.arange(0,len(cls)),columns=['cls']),
+        pd.DataFrame(cls,columns=['labels']),
+        pd.DataFrame(c_szs,columns=['size']),
+        pd.DataFrame(c_dist,columns=['dist'])
+    ], axis=1)
+    print(f'\nClassification dataset: {frmt_n(len(y))} records, {frmt_n(c)} classes')
+    if len(y.shape)>1: print(f'Total number of labels {[frmt_n(e) for e in y.shape]} -> {frmt_n(np.asarray(c_szs).sum())}')
+    display(df)
+
+def prep_cls(y, cls_to_idx=None, cls=None):
+    assert (type(y)==list or type(y)==np.ndarray)
+    
+    size,labels,cls2idx,cls2 = 0,None,None,None
+    if type(y)==list:
+        size = len(y)
+        labels = [str(e) for e in y]
+        if cls_to_idx is not None:
+            cls2idx = cls_to_idx
+            cls2 = [e for e in cls2idx]
+            for label in labels:
+                if label not in cls2:
+                    raise Exception(f'Label {label} not found in cls_to_idx')
+        else:
+            cls2 = sorted(list(set(labels)))
+            cls2idx = {cls2[i]: i for i in range(len(cls2))}
+        if type(y[0])==str:
+            y = [cls2idx[label] for label in labels]
+        y = np.asarray(y)
+        c_idxs = [(y==cls2idx[c]).nonzero()[0] for c in cls2idx]
+    else:
+        y1 = y.flatten()
+        size = len(y1)
+        cls1 = np.unique(y1)
+        c_idxs = [(y==cls1[c]).nonzero()[0] for c in cls1]
+        cls2 = cls or cls1
+    c_szs = [e.shape[0] for e in c_idxs]
+    c_dist = [e.shape[0]/size for e in c_idxs]
+    return y,cls2,len(cls2),labels,cls2idx,c_idxs,c_szs,c_dist
+
+def np_split(x, y, p=.8):
+    idx = np.random.permutation(x.shape[0])
+    k = int(x.shape[0]*p)
+    x,y = x[idx].copy(),y[idx].copy()
+    return x[:k],y[:k],x[k:],y[k:]
+
+
 def get_sample(x1, y1, x2, y2, sz=1000, sz2=None):
     if sz2 is None: sz2=sz
     p = np.random.permutation(len(x1))
@@ -170,11 +220,12 @@ def table(cols, vals):
     display(pd.DataFrame(vals, columns=cols))
 
 
-def show_dist(y):
-    df = pd.DataFrame(y, columns=['count'])['count'].value_counts()
-    df = pd.DataFrame(df, index=df.index, columns=['count'])
-    df['p'] = df['count']/sum(df['count'])
-    display(df)
+# Deprecated
+# def show_dist(y):
+#     df = pd.DataFrame(y, columns=['count'])['count'].value_counts()
+#     df = pd.DataFrame(df, index=df.index, columns=['count'])
+#     df['p'] = df['count']/sum(df['count'])
+#     display(df)
     # print(get_cls_dist_string(self.cls, self.c_szs, self.c_dist))
 
 
