@@ -1,5 +1,4 @@
 import numpy as np
-from sklearn.metrics import confusion_matrix
 import matplotlib.pyplot as plt
 import matplotlib as mpl
 from IPython.display import display
@@ -204,8 +203,8 @@ class Results_Clsf():
         if self.c!=2: raise ValueError('More than two classes')
         cm,cm_p = calc_cm(self.c, self.actuals, self.preds)
         plot_confusion(cm, cm_p)
-        display(pd.DataFrame(m.sum(axis=0)).transpose())
-        display(pd.DataFrame(m.sum(axis=1)))
+        display(pd.DataFrame(cm.sum(axis=0)).transpose())
+        display(pd.DataFrame(cm.sum(axis=1)))
         display(df_stats_by_class(cm))
     def stats(self, thresholds=10):
         if self.c!=2: raise ValueError('More than two classes')
